# ES2015

同一プロジェクト内で `babel-loader` か `buble-loader` を検出したとき、全ての `*.vue` ファイルの `<script>` タグを処理するためにそれらを使用し Vue コンポーネント内で ES2015 を使用できるようにします。もしあなたがまだ新しい言語機能を手に入れていないのであれば、学ぶべきです。いくつかのよい学習リソースはこちら:
- [Babel - Learn ES2015](https://babeljs.io/docs/learn-es2015/)
- [ES6 Features](https://github.com/lukehoban/es6features)
- [Exploring ES6 (book)](https://leanpub.com/exploring-es6)

他の Vue コンポーネントを読み込む際の典型的なパターンはこちらです:

``` html
<script>
import ComponentA from './ComponentA.vue'
import ComponentB from './ComponentB.vue'

export default {
  components: {
    ComponentA,
    ComponentB
  }
}
</script>
```

ここでは ES2015 のオブジェクトリテラルを使用して子コンポーネントを定義しています。`{ ComponentA }` は `{ ComponentA: ComponentA }` の簡略形です。 Vue は自動でキーを `component-a` に変換し、インポートされたコンポーネントをテンプレート内で `<component-a>` として使用することが出来ます。

### テンプレート内のES2015

`*.vue` ファイル内の `<template>` は JavaScript の render 関数にコンパイルされ[Buble](https://buble.surge.sh/guide/) のカスタムビルドで処理され ES2015 の機能をサポートします。これにより [Object shorthand properties](https://buble.surge.sh/guide/#object-shorthand-methods-and-properties-transforms-concisemethodproperty-) と[算出プロパティ](https://buble.surge.sh/guide/#computed-properties-transforms-computedproperty-)などの機能が使用できるようになります:

``` html
<div :class="[{ active: active }, isButton ? prefix + '-button' : null]">
```

次のように単純化することができます:

``` html
<div :class="{ active, [`${prefix}-button`]: isButton }">
```

**vue@^2.1.0 のみ利用可能:** `v-for` かスコープ付きスロットを使用することで、構造化されたパラメータを使用することが出来ます:

``` html
<li v-for="{ id, text } in items">
  {{ id }} {{ text }}
</li>
```

``` html
<my-component>
  <template scope="{ id, text }">
    <span>{{ id }} {{ text }}</span>
  </template>
</my-component>
```

[buble オプション](../options.md#buble)を使用してテンプレートでサポートされた機能をカスタマイズすることが出来ます。

### `.js` ファイルのトランスパイル

`vue-loader` は `*.vue` ファイルのみ処理するので、Webpack の設定ファイルに `babel-loader` または `buble-loader` を使って `*.js` ファイルを処理するように Webapck に指示する必要があります。 `vue-cli` でプロジェクトを作成しているとすでにそれは用意されています。

### `.babelrc` による Babel の設定

`babel-loader` は [`.babelrc`](https://babeljs.io/docs/usage/babelrc/)を遵守しているので、Babel のプリセットとプラグインで設定することが推奨されています。
